@@ -26,7 +26,7 @@
 #include "imageresult.h"
 #include "helpresult.h"
 
-#include <luajit-2.0/lua.hpp> // need the luajit-2.0 prefix to avoid conflicts with Lua 5.2
+#include <lua.hpp>
 
 #include <QDebug>
 #include <QString>
@@ -52,7 +52,7 @@ void LuaExpression::evaluate()
         QString cmd = command().simplified();
 
         if( cmd.startsWith(QLatin1String("show(")) || cmd.startsWith(QLatin1String("show (")) )
-            setResult(new Cantor::ImageResult(ret,ret));
+            setResult(new Cantor::ImageResult(QUrl::fromLocalFile(ret), ret));
         else
             setResult(new Cantor::TextResult(ret));
     }
