@@ -39,7 +39,7 @@ class ScilabBackend : public Cantor::Backend
         QWidget* settingsWidget(QWidget* parent) const;
         KConfigSkeleton* config() const;
 
-        KUrl helpUrl() const;
+        QUrl helpUrl() const;
         QString description() const;
 };
 
