@@ -23,7 +23,7 @@
 
 #include "cantor_export.h"
 
-#include <QtGui/QSyntaxHighlighter>
+#include <QSyntaxHighlighter>
 
 class QGraphicsTextItem;
 
@@ -52,11 +52,11 @@ class CANTOR_EXPORT DefaultHighlighter : public QSyntaxHighlighter
     ~DefaultHighlighter();
 
     /**
-     * Change the item beeing highlighted.
+     * Change the item being highlighted.
      */
     void setTextItem(QGraphicsTextItem* item);
 
-  public slots:
+  public Q_SLOTS:
     /**
      * Called when the cursor moved. Rehighlights accordingly.
      */
@@ -169,10 +169,10 @@ class CANTOR_EXPORT DefaultHighlighter : public QSyntaxHighlighter
      */
     virtual QString nonSeparatingCharacters() const;
 
-  private slots:
+  private Q_SLOTS:
     void updateFormats();
 
-  signals:
+  Q_SIGNALS:
     void rulesChanged();
 
   private:
